@@ -12,17 +12,18 @@
 
 #include <stdlib.h> // for RAND_MAX
 
-#include <kacceleratormanager.h>
-#include <klocalizedstring.h>
-#include <krandom.h>
+#include <KAcceleratorManager>
+#include <KLocalizedString>
+#include <KRandom>
 
-#include <qbuttongroup.h>
-#include <qgroupbox.h>
-#include <qevent.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qradiobutton.h>
-#include <qpushbutton.h>
+#include <QButtonGroup>
+#include <QGroupBox>
+#include <QEvent>
+#include <QLabel>
+#include <QLayout>
+#include <QRadioButton>
+#include <QPushButton>
+#include <QKeyEvent>
 
 #include "map.h"
 #include "settings.h"
@@ -175,7 +176,7 @@ void boxAsker::keyReleaseEvent(QKeyEvent *e)
 	else askWidget::keyReleaseEvent(e);
 }
 
-void boxAsker::nextQuestionHook(const QString &division)
+void boxAsker::nextQuestionHook(const division *div)
 {
 	QString otherDivision;
 	QStringList auxList;
@@ -189,11 +190,11 @@ void boxAsker::nextQuestionHook(const QString &division)
 
 	p_accept -> setEnabled(false);
 
-	auxList << division;
+	auxList << div -> getUntranslatedName ();
 
 	// we put the division in a random place
 	p_position = (int)((float)NB_CHOICES * KRandom::random() / (RAND_MAX + 1.0));
-	nextBoxAskerQuestionHook(division, p_position, true);
+	nextBoxAskerQuestionHook(div, p_position, true);
 
 	// fill the other names
 	j = 0;
@@ -201,10 +202,13 @@ void boxAsker::nextQuestionHook(const QString &division)
 	{
 		if (p_radioButtons[j] -> text().isNull() && p_radioButtons[j] -> icon().isNull())
 		{
-			otherDivision = p_map -> getRandomDivision(askMode());
-			while (auxList.contains(otherDivision))
-				otherDivision = p_map -> getRandomDivision(askMode());
-			if (nextBoxAskerQuestionHook(otherDivision, j, false))
+			division *otherDiv;
+			do
+			{
+				otherDiv = p_map -> getRandomDivision(askMode());
+				otherDivision = otherDiv -> getUntranslatedName();
+			} while (auxList.contains(otherDivision));
+			if (nextBoxAskerQuestionHook(otherDiv, j, false))
 				++j;
 			auxList << otherDivision;
 		}
