@@ -10,10 +10,10 @@
 
 #include "divisioncapitalasker.h"
 
-#include <klocalizedstring.h>
-#include <krandom.h>
+#include <KLocalizedString>
+#include <KRandom>
 
-#include <qradiobutton.h>
+#include <QRadioButton>
  
 #include "map.h"
 
@@ -22,20 +22,20 @@ divisionCapitalAsker::divisionCapitalAsker(QWidget *parent, KGmap *m, QWidget *w
 	init();
 }
 
-bool divisionCapitalAsker::nextBoxAskerQuestionHook(const QString &division, int i, bool isAnswer)
+bool divisionCapitalAsker::nextBoxAskerQuestionHook(const division *div, int i, bool isAnswer)
 {
 	bool b;
 	if (isAnswer)
 	{
-		QString divisionName = i18nc(p_map -> getFileName().toUtf8(), division.toUtf8());
-		setQuestion(i18nc("@title:group", p_map->getDivisionToCapitalQuestionPattern().toUtf8(), divisionName));
-		p_currentAnswer.setQuestion(i18nc("@item:intable column Question, %1 is region name", "%1", i18nc(p_map -> getFileName().toUtf8(), division.toUtf8())));
-		p_capital = p_map -> getDivisionCapital(division);
-		p_currentAnswer.setCorrectAnswer(i18nc("@option:radio The capital of <Region> is...", "%1", i18nc(p_map -> getFileName().toUtf8(), p_capital.toUtf8())));
-		p_radioButtons[i] -> setText(i18nc("@option:radio The capital of <Region> is...", "%1", i18nc(p_map -> getFileName().toUtf8(), p_capital.toUtf8())));
+		const QString divisionName = div -> getName();
+		setQuestion(p_map->getDivisionToCapitalQuestionPattern().subs(divisionName).toString());
+		p_currentAnswer.setQuestion(i18nc("@item:intable column Question, %1 is region name", "%1", divisionName));
+		p_capital = div -> getCapital();
+		p_currentAnswer.setCorrectAnswer(i18nc("@option:radio The capital of <Region> is...", "%1", p_capital));
+		p_radioButtons[i] -> setText(i18nc("@option:radio The capital of <Region> is...", "%1", p_capital));
 		b = true;
 		
-		QStringList falseCapitals = p_map -> getDivisionFalseCapitals(division);
+		QStringList falseCapitals = div -> getFalseCapitals();
 		int index = 0;
 		while (!falseCapitals.isEmpty() && index < 4)
 		{
@@ -44,7 +44,7 @@ bool divisionCapitalAsker::nextBoxAskerQuestionHook(const QString &division, int
 				int random = (int)((float)falseCapitals.size() * KRandom::random() / (RAND_MAX + 1.0));
 				QString falseCapital = falseCapitals.at(random);
 				falseCapitals.removeAt(random);
-				p_radioButtons[index] -> setText(i18nc("@option:radio The capital of <Region> is...", "%1", i18nc(p_map -> getFileName().toUtf8(), falseCapital.toUtf8())));
+				p_radioButtons[index] -> setText(i18nc("@option:radio The capital of <Region> is...", "%1", falseCapital));
 			}
 			++index;
 		}
@@ -52,7 +52,7 @@ bool divisionCapitalAsker::nextBoxAskerQuestionHook(const QString &division, int
 	else
 	{
 		QString capital;
-		capital = p_map -> getDivisionCapital(division);
+		capital = div -> getCapital();
 		// There are crazy countries like Norway where two different divisions
 		// have the same capital, avoid asking
 		// The capital of Akershus is ...
@@ -62,7 +62,7 @@ bool divisionCapitalAsker::nextBoxAskerQuestionHook(const QString &division, int
 		// Moss
 		if (capital != p_capital)
 		{
-			p_radioButtons[i] -> setText(i18nc("@option:radio The capital of <Region> is...", "%1", i18nc(p_map -> getFileName().toUtf8(), capital.toUtf8())));
+			p_radioButtons[i] -> setText(i18nc("@option:radio The capital of <Region> is...", "%1", capital));
 			b = true;
 		}
 		else b = false;
@@ -77,5 +77,5 @@ void divisionCapitalAsker::setAnswerHook(int userSays)
 
 QString divisionCapitalAsker::getQuestionHook() const
 {
-	return i18nc("@title", p_map->getDivisionToCapitalTitle().toUtf8());
+	return p_map->getDivisionToCapitalTitle();
 }
